@@ -86,7 +86,7 @@ def rotate_image(request):
     permission_checker = queryMultiAdapter((image, request, None), IViewContextPermissionChecker)
     if permission_checker is not None:
         permission = permission_checker.edit_permission
-        if not request.has_permission(permission, image):
+        if not request.has_permission(permission, context=image):
             raise HTTPForbidden()
     IImageFile(image).rotate(-90)
     # commit transaction to save blobs!
@@ -141,6 +141,7 @@ class ImageCropForm(AdminModalEditForm):
 
     fields = Fields(Interface)
     buttons = Buttons(IImageCropFormButtons)
+    has_border = True
 
     @handler(IImageCropFormButtons['crop'])
     def handle_crop(self, action):
@@ -258,6 +259,7 @@ class ImageSelectionForm(AdminModalEditForm):
 
     fields = Fields(Interface)
     buttons = Buttons(IImageSelectionFormButtons)
+    has_border = True
 
     selection_name = None
 
@@ -393,12 +395,18 @@ class ImageBannerSelectionForm(ImageSelectionForm):
     selection_name = 'banner'
 
 
+class ResponsiveImageSelectionForm(ImageSelectionForm):
+    """Responsive image selection form"""
+
+    selection_ratio = None
+
+
 #
 # XS responsive selection form
 #
 
 @viewlet_config(name='xs-selection.action', context=IResponsiveImage, layer=IAdminLayer,
-                view=IFileWidget, manager=IContextActionsViewletManager, weight=58)
+                view=IFileWidget, manager=IContextActionsViewletManager, weight=60)
 class ImageXSSelectionAction(ImageSelectionAction):
     """Image XS selection action"""
 
@@ -407,7 +415,7 @@ class ImageXSSelectionAction(ImageSelectionAction):
 
 
 @ajax_form_config(name='xs-selection.html', context=IResponsiveImage, layer=IPyAMSLayer)
-class ImageXSSelectionForm(ImageSelectionForm):
+class ImageXSSelectionForm(ResponsiveImageSelectionForm):
     """Image XS selection form"""
 
     selection_name = 'xs'
@@ -418,7 +426,7 @@ class ImageXSSelectionForm(ImageSelectionForm):
 #
 
 @viewlet_config(name='sm-selection.action', context=IResponsiveImage, layer=IAdminLayer,
-                view=IFileWidget, manager=IContextActionsViewletManager, weight=58)
+                view=IFileWidget, manager=IContextActionsViewletManager, weight=62)
 class ImageSMSelectionAction(ImageSelectionAction):
     """Image SM selection action"""
 
@@ -438,7 +446,7 @@ class ImageSMSelectionForm(ImageSelectionForm):
 #
 
 @viewlet_config(name='md-selection.action', context=IResponsiveImage, layer=IAdminLayer,
-                view=IFileWidget, manager=IContextActionsViewletManager, weight=58)
+                view=IFileWidget, manager=IContextActionsViewletManager, weight=64)
 class ImageMDSelectionAction(ImageSelectionAction):
     """Image MD selection action"""
 
@@ -458,7 +466,7 @@ class ImageMDSelectionForm(ImageSelectionForm):
 #
 
 @viewlet_config(name='lg-selection.action', context=IResponsiveImage, layer=IAdminLayer,
-                view=IFileWidget, manager=IContextActionsViewletManager, weight=58)
+                view=IFileWidget, manager=IContextActionsViewletManager, weight=66)
 class ImageLGSelectionAction(ImageSelectionAction):
     """Image LG selection action"""
 
@@ -478,7 +486,7 @@ class ImageLGSelectionForm(ImageSelectionForm):
 #
 
 @viewlet_config(name='xl-selection.action', context=IResponsiveImage, layer=IAdminLayer,
-                view=IFileWidget, manager=IContextActionsViewletManager, weight=58)
+                view=IFileWidget, manager=IContextActionsViewletManager, weight=68)
 class ImageXLSelectionAction(ImageSelectionAction):
     """Image XL selection action"""
 
